NAME = 'file-readers'
VERSION = '0.0.3'
DESCRIPTION = 'Library of different types of file reader and data collector classes.'
URL = 'https://github.com/mjalas/file-readers'
AUTHOR = 'Mats Jalas'
AUTHOR_EMAIL = 'mats.jalas@gmail.com'
LICENSE = 'MIT'
